==> copilot-24.4.10-sources.jar: com/vaadin/copilot/ide/IdeIntegration.java <==
/*
 * Copyright 2000-2024 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.copilot.ide;

import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.internal.ComponentTracker;
import com.vaadin.flow.component.internal.ComponentTracker.Location;
import com.vaadin.flow.server.startup.ApplicationConfiguration;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.File;

/**
 * Integration with IDEs for development mode.
 */
public final class IdeIntegration {

    private final ApplicationConfiguration configuration;

    /**
     * Creates a new integration with the given configuration.
     */
    public IdeIntegration(ApplicationConfiguration configuration) {
        this.configuration = configuration;
        if (configuration.isProductionMode()) {
            getLogger().error("{} should never be created in production mode",
                    getClass().getSimpleName());
        }

    }

    /**
     * Opens, in the current IDE, the location (file + line number) where the
     * given component was created.
     *
     * @param component
     *            the component to show
     */
    public void showComponentCreateInIde(Component component) {
        internalShowInIde(component, ComponentTracker.findCreate(component));
    }

    /**
     * Opens, in the current IDE, the location (file + line number) where the
     * given component was attached.
     *
     * @param component
     *            the component to show
     */
    public void showComponentAttachInIde(Component component) {
        internalShowInIde(component, ComponentTracker.findAttach(component));
    }

    private void internalShowInIde(Component component, Location location) {
        if (location == null) {
            getLogger().error(
                    "Unable to find the location where the component {} was created",
                    component.getClass().getName());
            return;
        }
        File javaFile = location.findJavaFile(configuration);
        if (javaFile == null || !javaFile.exists()) {
            getLogger().error("Unable to find file {}", javaFile);
            return;
        }

        IdeUtils.openFile(javaFile, location.lineNumber());
    }

    private static Logger getLogger() {
        return LoggerFactory.getLogger(IdeIntegration.class);
    }

}

==> copilot-24.4.20-sources.jar: com/vaadin/copilot/ide/IdeIntegration.java <==
/*
 * Copyright 2000-2024 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.vaadin.copilot.ide;

import com.vaadin.flow.component.Component;
import com.vaadin.flow.component.internal.ComponentTracker;
import com.vaadin.flow.component.internal.ComponentTracker.Location;
import com.vaadin.flow.server.startup.ApplicationConfiguration;
import java.io.File;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/** Integration with IDEs for development mode. */
public final class IdeIntegration {

    private final ApplicationConfiguration configuration;

    /** Creates a new integration with the given configuration. */
    public IdeIntegration(ApplicationConfiguration configuration) {
        this.configuration = configuration;
        if (configuration.isProductionMode()) {
            getLogger()
                    .error(
                            "{} should never be created in production mode",
                            getClass().getSimpleName());
        }
    }

    /**
     * Opens, in the current IDE, the location (file + line number) where the given component was created.
     *
     * @param component the component to show
     */
    public void showComponentCreateInIde(Component component) {
        internalShowInIde(component, ComponentTracker.findCreate(component));
    }

    /**
     * Opens, in the current IDE, the location (file + line number) where the given component was attached.
     *
     * @param component the component to show
     */
    public void showComponentAttachInIde(Component component) {
        internalShowInIde(component, ComponentTracker.findAttach(component));
    }

    private void internalShowInIde(Component component, Location location) {
        if (location == null) {
            getLogger()
                    .error(
                            "Unable to find the location where the component {} was created",
                            component.getClass().getName());
            return;
        }
        File javaFile = location.findJavaFile(configuration);
        if (javaFile == null || !javaFile.exists()) {
            getLogger().error("Unable to find file {}", javaFile);
            return;
        }

        IdeUtils.openFile(javaFile, location.lineNumber());
    }

    private static Logger getLogger() {
        return LoggerFactory.getLogger(IdeIntegration.class);
    }
}
